# The safedata_validator package

This package provides methods to validate XLSX files containing SAFE data formatted data and metada.

See the main documentation:
  [https://safedata_validator.readthedocs.io](https://safedata_validator.readthedocs.io)
